---
Title: Processing overview
Author: Jutta
---

Data processing therefore follows a tier-based approach \cite{km3comp}, where initial
filtering for particle interaction-related photon patterns (triggering of photon
``hits'') serves to create data at a first event-based data level.
In a second step, processing of the events, applying calibration,
particle reconstruction and data analysis methods leads to enhanced data sets,
requiring a high-performance computing infrastructure for flexible
application of modern data processing and data mining techniques.

For physics analyses, derivatives of these enriched data sets are
generated and their information is reduced to low-volume high-level data which can be
analysed and integrated locally into the analysis workflow of the
scientist, see Figure \ref{levels}. For interpretability of the data, a full Monte Carlo
simulation of the data generation and processing chain, starting at the
primary data level, is run to generate reference simulated data for
cross-checks at all processing stages and for statistic
interpretation of the particle measurements.

\begin{figure}
\includegraphics[width=\textwidth]{figs/Data_levels.pdf}
\caption{KM3NeT data levels related to open data publication, including data format description, user access rights and open data publication layer.} \label{levels}
\end{figure}

\subsection{Event-based data generation}

Data processing at the DAQ level follows paradigms of particle physics
and utilizes computing and software methodological approaches of this community. At
the shore stations, event triggering in the Data Acquisition (DAQ)
system leads to a significant reduction of the data stream. The data stream also includes relevant
instrumentation readouts for a comprehensive understanding of data taking
conditions. Photon-related information is written to
ROOT-based \cite{root} tree-like data structures and
accumulated during a predefined data taking time range of usually several
hours (so-called data runs) before being transferred to high-performance
computing (HPC) clusters. Instrumentation and environmental data
collected at the detector site are stored separately in a central database. Acoustic and other environmental data serve as basis for Earth and Sea-science initiatives. Access to this information following an Open Science
approach is under development, however, it will not be covered in the
scope of this report.

Both the complex process of neutrino detection in a natural environment and the low expected
count rate of the cosmic neutrino signal in comparison to atmospheric background events
necessitates the full modelling
of particle generation, detector response and data processing. To this
end, a dedicated simulation chain, starting form cosmic air-shower
particle generation or astrophysical neutrino flux assumptions, 
replicates the complete data-processing pipeline. At the event generation level, photon
distributions induced by these particles within the detection volume are
generated, masked by a simulation of the detector response and treated to
the same processing as measurements starting from the second data
level of the offline event format.


\subsection{Event data processing}

Processed event data sets at the second level represent input to physics analyses, e.g.~regarding neutrino oscillation and particle properties, and studies of
atmospheric and cosmic neutrino generation. Enriching the data to this
end involves probabilistic interpretation of temporal and spatial photon distributions for the
reconstruction of event properties in both measured and simulated
data, and requires high-performance computing capabilities. Due to the
distributed infrastructure of the KM3NeT building blocks and the
contribution of computing resources from various partners, data
processing will, in the final detector configuration, necessitate a
federated computing approach, the implementation of which is prepared through containerization
of the required software and testing of distributed resource management
approaches. In this context, the use of a middleware like e.g.~ DIRAC\footnote{Distributed Infrastructure with Remote Agent Control Interware, \url{http://diracgrid.org/}} is explored, again linking
closely to the particle physics community.

Access to data at this level is restricted to collaboration members due
to the intense use of computing resources, the large volume and complexity of the data and
the members' primary exploitation right of KM3NeT data. However, data at this stage is already converted to
HDF5\footnote{The HDF5 file format, \url{https://www.hdfgroup.org/}} format as a less customized hierarchical format. This format choice increases interoperability and facilitates the application of data analysis software packages used e.g.~in machine learning and helps to pave the way to wider
collaborations within the scientific community utilizing KM3NeT data.


\subsection{High level data and data derivatives}

\subsubsection{Summary formats and high-level data}

As mostly information on particle type, properties and direction is relevant for
the majority of physics analyses, a high-level summary format has been designed to
reduce the complex event information to simplified arrays
which allow for easy representation of an event data set as a table-like data structure.
Although this already leads to a reduced data volume, these neutrino
data sets are still dominated by atmospheric muon events at a ratio of about
$10^{6}:1$. Since for many analyses, atmospheric muons are considered background events to
both astrophysics and oscillation studies, publication of low-volume
general-purpose neutrino data sets requires further event filtering. Here, the choice of optimal filter criteria is usually dependent on the properties of the
expected flux of the signal neutrinos and performed using the simulated event sets.


\subsubsection{Event simulation derivatives as service}

To correctly judge the statistical significance of a measured neutrino event rate,
the full high-level simulation data sets are used in KM3NeT internal
studies to ensure a high accuracy of the count rate estimate. As handling
these large data sets is impractical for inter-experimental studies, but
the information is crucial for the interpretability of the data,
parameterized distributions of relevant observables need to be derived
from the simulation data sets and offered as services. Even in absence
of significant neutrino measurements in the construction phase of KM3NeT,
offering sensitivity estimates as in \cite{sensitivity} for given
models is beneficial for the development of common research goals and the development of a corresponding open service is currently under investigation.
